@@ -14,12 +14,9 @@ class HexFileSystemStorage(FileSystemStorage):
     def get_available_name(self, full_name):
         path, tail = os.path.split(full_name)
         name, ext = os.path.splitext(tail)
-        name = urlify(name)
+        name = urlify(name, max_length=None, remove_dots=False)
         if ext:
-            if ext.startswith('.'):
-                ext = '.' + urlify(ext[1:])
-            else:
-                ext = urlify(ext)
+            ext = urlify(ext, max_length=None, remove_dots=False)
         source_name = name
 
         while True:
@@ -35,5 +32,5 @@ class HexFileSystemStorage(FileSystemStorage):
                         raise FileWasFound()
                 break
             except FileWasFound:
-                name = source_name + ('-%08x' % random.randint(0, 0x100000000))
+                name = source_name + ('-%04x' % random.randint(0, 0x10000))
         return os.path.join(path, name + ext)
